from lisa_sdk import LisaPlugin


class LisaTranslationPlugin(LisaPlugin):
    def __init__(self):
        super().__init__()
        self.name = "lisa-translation-plugin"

    def get_name(self):
        return self.name




from setuptools import setup

setup(
    name='lisa_translation_plugin',
    packages=['lisa_translation_plugin'],
    version='0.1.2',
    description='A translation plugin to use with Lisa (Lightweight Improvable Software Assistant).',
    author='Xavier Saliniere',
    author_email='xavier.saliniere@openmailbox.org',
    url='https://bitbucket.org/lisadevteam/lisa-translation-plugin',
    download_url='https://bitbucket.org/lisadevteam/lisa-translation-plugin/get/master.zip',
    keywords=['plugin', 'translate', 'translation', 'lisa'],
    classifiers=[],
    requires=['lisa_sdk'],
    entry_points={
        'lisaplugins': [
            'lisa_translation_plugin = lisa_translation_plugin:LisaTranslationPlugin',
        ],
    },
)
